==> oci-java-sdk-shaded-full-3.40.0-sources.jar: com/oracle/bmc/datasafe/requests/UpdateAuditArchiveRetrievalRequest.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.datasafe.requests;

import com.oracle.bmc.datasafe.model.*;
/**
 * <b>Example: </b>Click <a
 * href="https://docs.cloud.oracle.com/en-us/iaas/tools/java-sdk-examples/3.40.0/datasafe/UpdateAuditArchiveRetrievalExample.java.html"
 * target="_blank" rel="noopener noreferrer">here</a> to see how to use
 * UpdateAuditArchiveRetrievalRequest.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20181201")
public class UpdateAuditArchiveRetrievalRequest
        extends com.oracle.bmc.requests.BmcRequest<
                com.oracle.bmc.datasafe.model.UpdateAuditArchiveRetrievalDetails> {

    /** OCID of the archive retrieval. */
    private String auditArchiveRetrievalId;

    /** OCID of the archive retrieval. */
    public String getAuditArchiveRetrievalId() {
        return auditArchiveRetrievalId;
    }
    /** Details to update the audit archive retrieval. */
    private com.oracle.bmc.datasafe.model.UpdateAuditArchiveRetrievalDetails
            updateAuditArchiveRetrievalDetails;

    /** Details to update the audit archive retrieval. */
    public com.oracle.bmc.datasafe.model.UpdateAuditArchiveRetrievalDetails
            getUpdateAuditArchiveRetrievalDetails() {
        return updateAuditArchiveRetrievalDetails;
    }
    /**
     * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
     * if-match parameter to the value of the etag from a previous GET or POST response for that
     * resource. The resource will be updated or deleted only if the etag you provide matches the
     * resource's current etag value.
     */
    private String ifMatch;

    /**
     * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
     * if-match parameter to the value of the etag from a previous GET or POST response for that
     * resource. The resource will be updated or deleted only if the etag you provide matches the
     * resource's current etag value.
     */
    public String getIfMatch() {
        return ifMatch;
    }
    /** Unique identifier for the request. */
    private String opcRequestId;

    /** Unique identifier for the request. */
    public String getOpcRequestId() {
        return opcRequestId;
    }

    /**
     * Alternative accessor for the body parameter.
     *
     * @return body parameter
     */
    @Override
    @com.oracle.bmc.InternalSdk
    public com.oracle.bmc.datasafe.model.UpdateAuditArchiveRetrievalDetails getBody$() {
        return updateAuditArchiveRetrievalDetails;
    }

    public static class Builder
            implements com.oracle.bmc.requests.BmcRequest.Builder<
                    UpdateAuditArchiveRetrievalRequest,
                    com.oracle.bmc.datasafe.model.UpdateAuditArchiveRetrievalDetails> {
        private com.oracle.bmc.http.client.RequestInterceptor invocationCallback = null;
        private com.oracle.bmc.retrier.RetryConfiguration retryConfiguration = null;

        /** OCID of the archive retrieval. */
        private String auditArchiveRetrievalId = null;

        /**
         * OCID of the archive retrieval.
         *
         * @param auditArchiveRetrievalId the value to set
         * @return this builder instance
         */
        public Builder auditArchiveRetrievalId(String auditArchiveRetrievalId) {
            this.auditArchiveRetrievalId = auditArchiveRetrievalId;
            return this;
        }

        /** Details to update the audit archive retrieval. */
        private com.oracle.bmc.datasafe.model.UpdateAuditArchiveRetrievalDetails
                updateAuditArchiveRetrievalDetails = null;

        /**
         * Details to update the audit archive retrieval.
         *
         * @param updateAuditArchiveRetrievalDetails the value to set
         * @return this builder instance
         */
        public Builder updateAuditArchiveRetrievalDetails(
                com.oracle.bmc.datasafe.model.UpdateAuditArchiveRetrievalDetails
                        updateAuditArchiveRetrievalDetails) {
            this.updateAuditArchiveRetrievalDetails = updateAuditArchiveRetrievalDetails;
            return this;
        }

        /**
         * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
         * if-match parameter to the value of the etag from a previous GET or POST response for that
         * resource. The resource will be updated or deleted only if the etag you provide matches
         * the resource's current etag value.
         */
        private String ifMatch = null;

        /**
         * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
         * if-match parameter to the value of the etag from a previous GET or POST response for that
         * resource. The resource will be updated or deleted only if the etag you provide matches
         * the resource's current etag value.
         *
         * @param ifMatch the value to set
         * @return this builder instance
         */
        public Builder ifMatch(String ifMatch) {
            this.ifMatch = ifMatch;
            return this;
        }

        /** Unique identifier for the request. */
        private String opcRequestId = null;

        /**
         * Unique identifier for the request.
         *
         * @param opcRequestId the value to set
         * @return this builder instance
         */
        public Builder opcRequestId(String opcRequestId) {
            this.opcRequestId = opcRequestId;
            return this;
        }

        /**
         * Set the invocation callback for the request to be built.
         *
         * @param invocationCallback the invocation callback to be set for the request
         * @return this builder instance
         */
        public Builder invocationCallback(
                com.oracle.bmc.http.client.RequestInterceptor invocationCallback) {
            this.invocationCallback = invocationCallback;
            return this;
        }

        /**
         * Set the retry configuration for the request to be built.
         *
         * @param retryConfiguration the retry configuration to be used for the request
         * @return this builder instance
         */
        public Builder retryConfiguration(
                com.oracle.bmc.retrier.RetryConfiguration retryConfiguration) {
            this.retryConfiguration = retryConfiguration;
            return this;
        }

        /**
         * Copy method to populate the builder with values from the given instance.
         *
         * @return this builder instance
         */
        public Builder copy(UpdateAuditArchiveRetrievalRequest o) {
            auditArchiveRetrievalId(o.getAuditArchiveRetrievalId());
            updateAuditArchiveRetrievalDetails(o.getUpdateAuditArchiveRetrievalDetails());
            ifMatch(o.getIfMatch());
            opcRequestId(o.getOpcRequestId());
            invocationCallback(o.getInvocationCallback());
            retryConfiguration(o.getRetryConfiguration());
            return this;
        }

        /**
         * Build the instance of UpdateAuditArchiveRetrievalRequest as configured by this builder
         *
         * <p>Note that this method takes calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#buildWithoutInvocationCallback} does not.
         *
         * <p>This is the preferred method to build an instance.
         *
         * @return instance of UpdateAuditArchiveRetrievalRequest
         */
        public UpdateAuditArchiveRetrievalRequest build() {
            UpdateAuditArchiveRetrievalRequest request = buildWithoutInvocationCallback();
            request.setInvocationCallback(invocationCallback);
            request.setRetryConfiguration(retryConfiguration);
            return request;
        }

        /**
         * Alternative setter for the body parameter.
         *
         * @param body the body parameter
         * @return this builder instance
         */
        @com.oracle.bmc.InternalSdk
        public Builder body$(
                com.oracle.bmc.datasafe.model.UpdateAuditArchiveRetrievalDetails body) {
            updateAuditArchiveRetrievalDetails(body);
            return this;
        }

        /**
         * Build the instance of UpdateAuditArchiveRetrievalRequest as configured by this builder
         *
         * <p>Note that this method does not take calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#build} does
         *
         * @return instance of UpdateAuditArchiveRetrievalRequest
         */
        public UpdateAuditArchiveRetrievalRequest buildWithoutInvocationCallback() {
            UpdateAuditArchiveRetrievalRequest request = new UpdateAuditArchiveRetrievalRequest();
            request.auditArchiveRetrievalId = auditArchiveRetrievalId;
            request.updateAuditArchiveRetrievalDetails = updateAuditArchiveRetrievalDetails;
            request.ifMatch = ifMatch;
            request.opcRequestId = opcRequestId;
            return request;
            // new UpdateAuditArchiveRetrievalRequest(auditArchiveRetrievalId,
            // updateAuditArchiveRetrievalDetails, ifMatch, opcRequestId);
        }
    }

    /**
     * Return an instance of {@link Builder} that allows you to modify request properties.
     *
     * @return instance of {@link Builder} that allows you to modify request properties.
     */
    public Builder toBuilder() {
        return new Builder()
                .auditArchiveRetrievalId(auditArchiveRetrievalId)
                .updateAuditArchiveRetrievalDetails(updateAuditArchiveRetrievalDetails)
                .ifMatch(ifMatch)
                .opcRequestId(opcRequestId);
    }

    /**
     * Return a new builder for this request object.
     *
     * @return builder for the request object
     */
    public static Builder builder() {
        return new Builder();
    }

    @Override
    public String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("(");
        sb.append("super=").append(super.toString());
        sb.append(",auditArchiveRetrievalId=").append(String.valueOf(this.auditArchiveRetrievalId));
        sb.append(",updateAuditArchiveRetrievalDetails=")
                .append(String.valueOf(this.updateAuditArchiveRetrievalDetails));
        sb.append(",ifMatch=").append(String.valueOf(this.ifMatch));
        sb.append(",opcRequestId=").append(String.valueOf(this.opcRequestId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof UpdateAuditArchiveRetrievalRequest)) {
            return false;
        }

        UpdateAuditArchiveRetrievalRequest other = (UpdateAuditArchiveRetrievalRequest) o;
        return super.equals(o)
                && java.util.Objects.equals(
                        this.auditArchiveRetrievalId, other.auditArchiveRetrievalId)
                && java.util.Objects.equals(
                        this.updateAuditArchiveRetrievalDetails,
                        other.updateAuditArchiveRetrievalDetails)
                && java.util.Objects.equals(this.ifMatch, other.ifMatch)
                && java.util.Objects.equals(this.opcRequestId, other.opcRequestId);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.auditArchiveRetrievalId == null
                                ? 43
                                : this.auditArchiveRetrievalId.hashCode());
        result =
                (result * PRIME)
                        + (this.updateAuditArchiveRetrievalDetails == null
                                ? 43
                                : this.updateAuditArchiveRetrievalDetails.hashCode());
        result = (result * PRIME) + (this.ifMatch == null ? 43 : this.ifMatch.hashCode());
        result = (result * PRIME) + (this.opcRequestId == null ? 43 : this.opcRequestId.hashCode());
        return result;
    }
}

==> oci-java-sdk-shaded-full-3.48.0-sources.jar: com/oracle/bmc/datasafe/requests/UpdateAuditArchiveRetrievalRequest.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.datasafe.requests;

import com.oracle.bmc.datasafe.model.*;
/**
 * <b>Example: </b>Click <a
 * href="https://docs.cloud.oracle.com/en-us/iaas/tools/java-sdk-examples/latest/datasafe/UpdateAuditArchiveRetrievalExample.java.html"
 * target="_blank" rel="noopener noreferrer">here</a> to see how to use
 * UpdateAuditArchiveRetrievalRequest.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20181201")
public class UpdateAuditArchiveRetrievalRequest
        extends com.oracle.bmc.requests.BmcRequest<
                com.oracle.bmc.datasafe.model.UpdateAuditArchiveRetrievalDetails> {

    /** OCID of the archive retrieval. */
    private String auditArchiveRetrievalId;

    /** OCID of the archive retrieval. */
    public String getAuditArchiveRetrievalId() {
        return auditArchiveRetrievalId;
    }
    /** Details to update the audit archive retrieval. */
    private com.oracle.bmc.datasafe.model.UpdateAuditArchiveRetrievalDetails
            updateAuditArchiveRetrievalDetails;

    /** Details to update the audit archive retrieval. */
    public com.oracle.bmc.datasafe.model.UpdateAuditArchiveRetrievalDetails
            getUpdateAuditArchiveRetrievalDetails() {
        return updateAuditArchiveRetrievalDetails;
    }
    /**
     * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
     * if-match parameter to the value of the etag from a previous GET or POST response for that
     * resource. The resource will be updated or deleted only if the etag you provide matches the
     * resource's current etag value.
     */
    private String ifMatch;

    /**
     * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
     * if-match parameter to the value of the etag from a previous GET or POST response for that
     * resource. The resource will be updated or deleted only if the etag you provide matches the
     * resource's current etag value.
     */
    public String getIfMatch() {
        return ifMatch;
    }
    /** Unique identifier for the request. */
    private String opcRequestId;

    /** Unique identifier for the request. */
    public String getOpcRequestId() {
        return opcRequestId;
    }

    /**
     * Alternative accessor for the body parameter.
     *
     * @return body parameter
     */
    @Override
    @com.oracle.bmc.InternalSdk
    public com.oracle.bmc.datasafe.model.UpdateAuditArchiveRetrievalDetails getBody$() {
        return updateAuditArchiveRetrievalDetails;
    }

    public static class Builder
            implements com.oracle.bmc.requests.BmcRequest.Builder<
                    UpdateAuditArchiveRetrievalRequest,
                    com.oracle.bmc.datasafe.model.UpdateAuditArchiveRetrievalDetails> {
        private com.oracle.bmc.http.client.RequestInterceptor invocationCallback = null;
        private com.oracle.bmc.retrier.RetryConfiguration retryConfiguration = null;

        /** OCID of the archive retrieval. */
        private String auditArchiveRetrievalId = null;

        /**
         * OCID of the archive retrieval.
         *
         * @param auditArchiveRetrievalId the value to set
         * @return this builder instance
         */
        public Builder auditArchiveRetrievalId(String auditArchiveRetrievalId) {
            this.auditArchiveRetrievalId = auditArchiveRetrievalId;
            return this;
        }

        /** Details to update the audit archive retrieval. */
        private com.oracle.bmc.datasafe.model.UpdateAuditArchiveRetrievalDetails
                updateAuditArchiveRetrievalDetails = null;

        /**
         * Details to update the audit archive retrieval.
         *
         * @param updateAuditArchiveRetrievalDetails the value to set
         * @return this builder instance
         */
        public Builder updateAuditArchiveRetrievalDetails(
                com.oracle.bmc.datasafe.model.UpdateAuditArchiveRetrievalDetails
                        updateAuditArchiveRetrievalDetails) {
            this.updateAuditArchiveRetrievalDetails = updateAuditArchiveRetrievalDetails;
            return this;
        }

        /**
         * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
         * if-match parameter to the value of the etag from a previous GET or POST response for that
         * resource. The resource will be updated or deleted only if the etag you provide matches
         * the resource's current etag value.
         */
        private String ifMatch = null;

        /**
         * For optimistic concurrency control. In the PUT or DELETE call for a resource, set the
         * if-match parameter to the value of the etag from a previous GET or POST response for that
         * resource. The resource will be updated or deleted only if the etag you provide matches
         * the resource's current etag value.
         *
         * @param ifMatch the value to set
         * @return this builder instance
         */
        public Builder ifMatch(String ifMatch) {
            this.ifMatch = ifMatch;
            return this;
        }

        /** Unique identifier for the request. */
        private String opcRequestId = null;

        /**
         * Unique identifier for the request.
         *
         * @param opcRequestId the value to set
         * @return this builder instance
         */
        public Builder opcRequestId(String opcRequestId) {
            this.opcRequestId = opcRequestId;
            return this;
        }

        /**
         * Set the invocation callback for the request to be built.
         *
         * @param invocationCallback the invocation callback to be set for the request
         * @return this builder instance
         */
        public Builder invocationCallback(
                com.oracle.bmc.http.client.RequestInterceptor invocationCallback) {
            this.invocationCallback = invocationCallback;
            return this;
        }

        /**
         * Set the retry configuration for the request to be built.
         *
         * @param retryConfiguration the retry configuration to be used for the request
         * @return this builder instance
         */
        public Builder retryConfiguration(
                com.oracle.bmc.retrier.RetryConfiguration retryConfiguration) {
            this.retryConfiguration = retryConfiguration;
            return this;
        }

        /**
         * Copy method to populate the builder with values from the given instance.
         *
         * @return this builder instance
         */
        public Builder copy(UpdateAuditArchiveRetrievalRequest o) {
            auditArchiveRetrievalId(o.getAuditArchiveRetrievalId());
            updateAuditArchiveRetrievalDetails(o.getUpdateAuditArchiveRetrievalDetails());
            ifMatch(o.getIfMatch());
            opcRequestId(o.getOpcRequestId());
            invocationCallback(o.getInvocationCallback());
            retryConfiguration(o.getRetryConfiguration());
            return this;
        }

        /**
         * Build the instance of UpdateAuditArchiveRetrievalRequest as configured by this builder
         *
         * <p>Note that this method takes calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#buildWithoutInvocationCallback} does not.
         *
         * <p>This is the preferred method to build an instance.
         *
         * @return instance of UpdateAuditArchiveRetrievalRequest
         */
        public UpdateAuditArchiveRetrievalRequest build() {
            UpdateAuditArchiveRetrievalRequest request = buildWithoutInvocationCallback();
            request.setInvocationCallback(invocationCallback);
            request.setRetryConfiguration(retryConfiguration);
            return request;
        }

        /**
         * Alternative setter for the body parameter.
         *
         * @param body the body parameter
         * @return this builder instance
         */
        @com.oracle.bmc.InternalSdk
        public Builder body$(
                com.oracle.bmc.datasafe.model.UpdateAuditArchiveRetrievalDetails body) {
            updateAuditArchiveRetrievalDetails(body);
            return this;
        }

        /**
         * Build the instance of UpdateAuditArchiveRetrievalRequest as configured by this builder
         *
         * <p>Note that this method does not take calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#build} does
         *
         * @return instance of UpdateAuditArchiveRetrievalRequest
         */
        public UpdateAuditArchiveRetrievalRequest buildWithoutInvocationCallback() {
            UpdateAuditArchiveRetrievalRequest request = new UpdateAuditArchiveRetrievalRequest();
            request.auditArchiveRetrievalId = auditArchiveRetrievalId;
            request.updateAuditArchiveRetrievalDetails = updateAuditArchiveRetrievalDetails;
            request.ifMatch = ifMatch;
            request.opcRequestId = opcRequestId;
            return request;
            // new UpdateAuditArchiveRetrievalRequest(auditArchiveRetrievalId,
            // updateAuditArchiveRetrievalDetails, ifMatch, opcRequestId);
        }
    }

    /**
     * Return an instance of {@link Builder} that allows you to modify request properties.
     *
     * @return instance of {@link Builder} that allows you to modify request properties.
     */
    public Builder toBuilder() {
        return new Builder()
                .auditArchiveRetrievalId(auditArchiveRetrievalId)
                .updateAuditArchiveRetrievalDetails(updateAuditArchiveRetrievalDetails)
                .ifMatch(ifMatch)
                .opcRequestId(opcRequestId);
    }

    /**
     * Return a new builder for this request object.
     *
     * @return builder for the request object
     */
    public static Builder builder() {
        return new Builder();
    }

    @Override
    public String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("(");
        sb.append("super=").append(super.toString());
        sb.append(",auditArchiveRetrievalId=").append(String.valueOf(this.auditArchiveRetrievalId));
        sb.append(",updateAuditArchiveRetrievalDetails=")
                .append(String.valueOf(this.updateAuditArchiveRetrievalDetails));
        sb.append(",ifMatch=").append(String.valueOf(this.ifMatch));
        sb.append(",opcRequestId=").append(String.valueOf(this.opcRequestId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof UpdateAuditArchiveRetrievalRequest)) {
            return false;
        }

        UpdateAuditArchiveRetrievalRequest other = (UpdateAuditArchiveRetrievalRequest) o;
        return super.equals(o)
                && java.util.Objects.equals(
                        this.auditArchiveRetrievalId, other.auditArchiveRetrievalId)
                && java.util.Objects.equals(
                        this.updateAuditArchiveRetrievalDetails,
                        other.updateAuditArchiveRetrievalDetails)
                && java.util.Objects.equals(this.ifMatch, other.ifMatch)
                && java.util.Objects.equals(this.opcRequestId, other.opcRequestId);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.auditArchiveRetrievalId == null
                                ? 43
                                : this.auditArchiveRetrievalId.hashCode());
        result =
                (result * PRIME)
                        + (this.updateAuditArchiveRetrievalDetails == null
                                ? 43
                                : this.updateAuditArchiveRetrievalDetails.hashCode());
        result = (result * PRIME) + (this.ifMatch == null ? 43 : this.ifMatch.hashCode());
        result = (result * PRIME) + (this.opcRequestId == null ? 43 : this.opcRequestId.hashCode());
        return result;
    }
}
